class TokenAccountsByOwner {
  String? jsonrpc;
  Result? result;
  int? id;

  TokenAccountsByOwner({this.jsonrpc, this.result, this.id});

  TokenAccountsByOwner.fromJson(Map<String, dynamic> json) {
    jsonrpc = json['jsonrpc'];
    result =
        json['result'] != null ? new Result.fromJson(json['result']) : null;
    id = json['id'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['jsonrpc'] = this.jsonrpc;
    if (this.result != null) {
      data['result'] = this.result!.toJson();
    }
    data['id'] = this.id;
    return data;
  }
}

class Result {
  Context? context;
  List<Value>? value;

  Result({this.context, this.value});

  Result.fromJson(Map<String, dynamic> json) {
    context =
        json['context'] != null ? new Context.fromJson(json['context']) : null;
    if (json['value'] != null) {
      value = <Value>[];
      json['value'].forEach((v) {
        value!.add(new Value.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    if (this.context != null) {
      data['context'] = this.context!.toJson();
    }
    if (this.value != null) {
      data['value'] = this.value!.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class Context {
  int? slot;

  Context({this.slot});

  Context.fromJson(Map<String, dynamic> json) {
    slot = json['slot'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['slot'] = this.slot;
    return data;
  }
}

class Value {
  Account? account;
  String? pubkey;

  Value({this.account, this.pubkey});

  Value.fromJson(Map<String, dynamic> json) {
    account =
        json['account'] != null ? new Account.fromJson(json['account']) : null;
    pubkey = json['pubkey'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    if (this.account != null) {
      data['account'] = this.account!.toJson();
    }
    data['pubkey'] = this.pubkey;
    return data;
  }
}

class Account {
  Data? data;
  bool? executable;
  int? lamports;
  String? owner;
  int? rentEpoch;

  Account(
      {this.data, this.executable, this.lamports, this.owner, this.rentEpoch});

  Account.fromJson(Map<String, dynamic> json) {
    data = json['data'] != null ? new Data.fromJson(json['data']) : null;
    executable = json['executable'];
    lamports = json['lamports'];
    owner = json['owner'];
    rentEpoch = json['rentEpoch'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    if (this.data != null) {
      data['data'] = this.data!.toJson();
    }
    data['executable'] = this.executable;
    data['lamports'] = this.lamports;
    data['owner'] = this.owner;
    data['rentEpoch'] = this.rentEpoch;
    return data;
  }
}

class Data {
  Parsed? parsed;
  String? program;
  int? space;

  Data({this.parsed, this.program, this.space});

  Data.fromJson(Map<String, dynamic> json) {
    parsed =
        json['parsed'] != null ? new Parsed.fromJson(json['parsed']) : null;
    program = json['program'];
    space = json['space'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    if (this.parsed != null) {
      data['parsed'] = this.parsed!.toJson();
    }
    data['program'] = this.program;
    data['space'] = this.space;
    return data;
  }
}

class Parsed {
  Info? info;
  String? type;

  Parsed({this.info, this.type});

  Parsed.fromJson(Map<String, dynamic> json) {
    info = json['info'] != null ? new Info.fromJson(json['info']) : null;
    type = json['type'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    if (this.info != null) {
      data['info'] = this.info!.toJson();
    }
    data['type'] = this.type;
    return data;
  }
}

class Info {
  bool? isNative;
  String? mint;
  String? owner;
  RentExemptReserve? rentExemptReserve;
  String? state;
  TokenAmount? tokenAmount;

  Info(
      {this.isNative,
      this.mint,
      this.owner,
      this.rentExemptReserve,
      this.state,
      this.tokenAmount});

  Info.fromJson(Map<String, dynamic> json) {
    isNative = json['isNative'];
    mint = json['mint'];
    owner = json['owner'];
    rentExemptReserve = json['rentExemptReserve'] != null
        ? new RentExemptReserve.fromJson(json['rentExemptReserve'])
        : null;
    state = json['state'];
    tokenAmount = json['tokenAmount'] != null
        ? new TokenAmount.fromJson(json['tokenAmount'])
        : null;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['isNative'] = this.isNative;
    data['mint'] = this.mint;
    data['owner'] = this.owner;
    if (this.rentExemptReserve != null) {
      data['rentExemptReserve'] = this.rentExemptReserve!.toJson();
    }
    data['state'] = this.state;
    if (this.tokenAmount != null) {
      data['tokenAmount'] = this.tokenAmount!.toJson();
    }
    return data;
  }
}

class RentExemptReserve {
  String? amount;
  int? decimals;
  double? uiAmount;
  String? uiAmountString;

  RentExemptReserve(
      {this.amount, this.decimals, this.uiAmount, this.uiAmountString});

  RentExemptReserve.fromJson(Map<String, dynamic> json) {
    amount = json['amount'];
    decimals = json['decimals'];
    uiAmount = json['uiAmount'];
    uiAmountString = json['uiAmountString'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['amount'] = this.amount;
    data['decimals'] = this.decimals;
    data['uiAmount'] = this.uiAmount;
    data['uiAmountString'] = this.uiAmountString;
    return data;
  }
}

class TokenAmount {
  String? amount;
  int? decimals;
  double? uiAmount;
  String? uiAmountString;

  TokenAmount({this.amount, this.decimals, this.uiAmount, this.uiAmountString});

  TokenAmount.fromJson(Map<String, dynamic> json) {
    amount = json['amount'];
    decimals = json['decimals'];
    uiAmount = json['uiAmount'];
    uiAmountString = json['uiAmountString'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['amount'] = this.amount;
    data['decimals'] = this.decimals;
    data['uiAmount'] = this.uiAmount;
    data['uiAmountString'] = this.uiAmountString;
    return data;
  }
}
